==> open-xchange-guard_2.8.0.orig.tar.bz2: open-xchange-guard-2.8.0/com.openexchange.guard/src/com/openexchange/guard/servlets/keymanagement/responses/GuardKeyInfoCollectionResponse.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.servlets.keymanagement.responses;

import java.util.ArrayList;
import java.util.Arrays;
import com.openexchange.guard.keymanagement.commons.GuardKeys;

/**
 * {@link GuardKeyInfoCollectionResponse}
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.6.0
 */
public class GuardKeyInfoCollectionResponse {

    private final Iterable<GuardKeys> guardKeys;

    /**
     * Initializes a new {@link GuardKeyInfoCollectionResponse}.
     *
     * @param guardKeyInfoResponses
     */
    public GuardKeyInfoCollectionResponse(GuardKeys...guardKeyInfoResponses) {
        this(Arrays.asList(guardKeyInfoResponses));
    }

    /**
     * Initializes a new {@link GuardKeyInfoCollectionResponse}.
     *
     * @param guardKeyInfoResponses
     */
    public GuardKeyInfoCollectionResponse(Iterable<GuardKeys> guardKeyInfoResponses) {
        this.guardKeys = guardKeyInfoResponses;
    }

    public GuardKeyInfoResponse[] getKeyRings() {
        ArrayList<GuardKeyInfoResponse> ret = new ArrayList<GuardKeyInfoResponse>();
        for(GuardKeys key : guardKeys) {
            ret.add(new GuardKeyInfoResponse(key));
        }
        return ret.toArray(new GuardKeyInfoResponse[ret.size()]);
    }
}

==> open-xchange-guard_2.10.3.orig.tar.bz2: open-xchange-guard-2.10.3/com.openexchange.guard/src/com/openexchange/guard/servlets/keymanagement/responses/GuardKeyInfoCollectionResponse.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.servlets.keymanagement.responses;

import java.util.ArrayList;
import java.util.Arrays;
import com.openexchange.guard.keymanagement.commons.GuardKeys;

/**
 * {@link GuardKeyInfoCollectionResponse}
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.6.0
 */
public class GuardKeyInfoCollectionResponse {

    private final Iterable<GuardKeys> guardKeys;
    private final String password;

    /**
     * Initializes a new {@link GuardKeyInfoCollectionResponse}.
     *
     * @param guardKeyInfoResponses
     */
    public GuardKeyInfoCollectionResponse(GuardKeys...guardKeyInfoResponses) {
        this(null, Arrays.asList(guardKeyInfoResponses));
    }

    /**
     * Initializes a new {@link GuardKeyInfoCollectionResponse}.
     *
     * @param The password of the private keys rings
     * @param guardKeyInfoResponses
     */
    public GuardKeyInfoCollectionResponse(String password, GuardKeys...guardKeyInfoResponses) {
        this(password, Arrays.asList(guardKeyInfoResponses));
    }

    /**
     * Initializes a new {@link GuardKeyInfoCollectionResponse}.
     *
     * @param guardKeyInfoResponses
     */
    public GuardKeyInfoCollectionResponse(Iterable<GuardKeys> guardKeyInfoResponses) {
        this(null, guardKeyInfoResponses);
    }

    /**
     * Initializes a new {@link GuardKeyInfoCollectionResponse}.
     *
     * @param The password of the private keys rings
     * @param guardKeyInfoResponses
     */
    public GuardKeyInfoCollectionResponse(String password, Iterable<GuardKeys> guardKeyInfoResponses) {
        this.password = password;
        this.guardKeys = guardKeyInfoResponses;
    }

    public GuardKeyInfoResponse[] getKeyRings() {
        ArrayList<GuardKeyInfoResponse> ret = new ArrayList<GuardKeyInfoResponse>();
        for(GuardKeys key : guardKeys) {
            ret.add(new GuardKeyInfoResponse(key, password));
        }
        return ret.toArray(new GuardKeyInfoResponse[ret.size()]);
    }
}
